@@ -44,6 +44,7 @@ USER_API_KEY = "user_api_key"
 READONLY_AUTH_KEY = "watcher_readonly_key"
 WATCHER_SERVICE_KEY = "watcher_service"
 WATCHER_PORT_KEY = "watcher_port"
+WATCHER_IMAGE_TAG_KEY = "watcher_image_tag"
 ENDPOINT_PORTS_KEY = "endpoint_ports"
 TEMPLATE_ID_FIELD = "id_field"
 TEMPLATE_ID_KEY = "deployment_id"
@@ -106,6 +107,32 @@ def is_storage_compatible():
         return False
 ################
 
+def parse_key_value_pairs(input_str: str) -> dict:
+    """Parse key=value pairs from a string into a dictionary.
+    
+    Args:
+        input_str: String containing key=value pairs separated by commas
+        
+    Returns:
+        Dictionary with parsed key-value pairs
+        
+    Raises:
+        ValueError: If any pair is not in key=value format
+    """
+    if not input_str.strip():
+        return {}
+    
+    result = {}
+    for pair in input_str.split(','):
+        pair = pair.strip()
+        if not pair:
+            continue
+        if '=' not in pair:
+            raise ValueError(f"Invalid key=value pair: '{pair}'. Expected format: key=value")
+        key, value = pair.split('=', 1)
+        result[key.strip()] = value.strip()
+    return result
+
 def extract_auth_token(headers):
     """
     Extract auth token. Valid headers:
@@ -129,8 +156,19 @@ def extract_auth_token(headers):
         return {"error": str(e)}
 
 
-def generate_compose_config(role, node_name, mtu="1420", target_platform="amd64", write_to_file=True, node_ip_address="0.0.0.0", num_gpus=0, node_labels=None, pool_ip=None, vpn_token=None, pool_token=None):
-    
+def generate_compose_config(
+    role,
+    node_name,
+    mtu="1420",
+    target_platform="amd64",
+    write_to_file=True,
+    node_ip_address="0.0.0.0",
+    num_gpus=0,
+    node_labels=None,
+    pool_ip=None,
+    vpn_token=None,
+    pool_token=None
+):
     if node_labels is not None:
         node_labels = " ".join([f"--node-label {key}={value}" for key, value in node_labels.items()])
     rand_suffix = uuid.uuid4().hex[:8]
